@@ -990,8 +990,6 @@ class SoftwarePropertiesQt(SoftwareProperties):
     elif (desktop == 'XFCE' and
       os.path.exists('/usr/bin/xfce4-session-logout')):
       subprocess.call(['xfce4-session-logout'])
-    elif (desktop == 'LXDE' and os.path.exists('/usr/bin/lubuntu-logout')):
-      subprocess.call(['lubuntu-logout'])
     elif (desktop == 'LXQt' and os.path.exists('/usr/bin/lxqt-leave')):
       subprocess.call(['lxqt-leave'])
 
